@@ -1,19 +1,20 @@
-/// A module for managing a Google API access token
-use goauth::{
-    auth::{JwtClaims, Token},
-    credentials::Credentials,
-};
-use log::*;
-use smpl_jwt::Jwt;
-use std::{
-    sync::{
-        atomic::{AtomicBool, Ordering},
-        {Arc, RwLock},
-    },
-    time::Instant,
-};
-
 pub use goauth::scopes::Scope;
+/// A module for managing a Google API access token
+use {
+    goauth::{
+        auth::{JwtClaims, Token},
+        credentials::Credentials,
+    },
+    log::*,
+    smpl_jwt::Jwt,
+    std::{
+        sync::{
+            atomic::{AtomicBool, Ordering},
+            {Arc, RwLock},
+        },
+        time::Instant,
+    },
+};
 
 fn load_credentials() -> Result<Credentials, String> {
     // Use standard GOOGLE_APPLICATION_CREDENTIALS environment variable
